@@ -15,7 +15,11 @@
 #' avail <- BiocManager::available()
 #' length(avail)
 #'
-#' BiocManager::available("bs.*hsapiens")
+#' grep("bs.*hsapiens", avail, value = TRUE, ignore.case = TRUE)
+#'
+#' \dontrun{
+#'   BiocManager::available("bs.*hsapiens")
+#' }
 #'
 #' @md
 #' @export
@@ -27,9 +31,12 @@ available <-
         is.logical(include_installed), length(include_installed) == 1L,
         !is.na(include_installed)
     )
-    repos <- repositories()
-    answer <- rownames(available.packages(repos = repos))
-    answer <- grep(pattern, answer, value = TRUE, ignore.case = TRUE)
+
+    answer <- character()
+    repos <- .repositories_filter(repositories())
+    if (length(repos))
+        answer <- rownames(.inet_available.packages(repos = repos))
+    answer <- sort(grep(pattern, answer, value = TRUE, ignore.case = TRUE))
     if (!include_installed)
         answer <- setdiff(answer, rownames(installed.packages()))
     answer
