@@ -26,7 +26,18 @@ test_that(".install_repos() works", {
     .skip_if_misconfigured()
     skip_if_offline()
     repos <- repositories()
-    expect_identical(character(0), .install_repos(character(), repos = repos))
+    old_pkgs <- matrix(
+        c("pkgB", "/home/user/dir"), 1, 2,
+        dimnames=list("pkgB", c("Package", "LibPath")))
+    inst_pkgs <- matrix(
+        c("pkgA", "/home/user/dir"), 1, 2,
+        dimnames=list("pkgA", c("Package", "LibPath")))
+    expect_identical(
+        character(0),
+        .install_repos(
+            character(), old_pkgs, inst_pkgs, repos = repos, force = FALSE
+        )
+    )
 })
 
 test_that(".install_github() works", {
@@ -51,6 +62,29 @@ test_that("Versions are checked in install", {
     expect_error(install(version = "3.4.2"))
 })
 
+test_that("pkgs are not re-downloaded when force=FALSE", {
+    .filter <- BiocManager:::.install_filter_up_to_date
+
+    old_pkgs <- matrix(
+        c("pkgB", "/home/user/dir"), 1, 2,
+        dimnames=list("pkgB", c("Package", "LibPath")))
+    inst_pkgs <- matrix(
+        c("pkgA", "pkgB", "/home/user/dir", "/home/user/dir"), 2, 2,
+        dimnames=list(c("pkgA", "pkgB"), c("Package", "LibPath")))
+
+    # installed and not old
+    expect_warning(.filter("pkgA", inst_pkgs, old_pkgs, FALSE))
+    # installed and not old but force
+    expect_identical(.filter("pkgA", inst_pkgs, old_pkgs, TRUE), "pkgA")
+
+    # installed and old
+    expect_identical(.filter("pkgB", inst_pkgs, old_pkgs, FALSE), "pkgB")
+    expect_identical(.filter("pkgB", inst_pkgs, old_pkgs, TRUE), "pkgB")
+
+    # not installed and no info on old
+    expect_identical(.filter("pkgC", inst_pkgs, old_pkgs, FALSE), "pkgC")
+})
+
 context("install(update = TRUE) filters un-updatable packages")
 
 test_that("masked packages are filtered", {
